NLSL: qrutil.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
qrutil.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | qtbvec (m, n, q, ldq, qraux, b, qtb)
subroutine | rsolve (m, n, q, ldq, qraux, qtb, x, rcalc, rsd)

## Function/Subroutine Documentation

subroutine qtbvec | ( | integer | m,
|  | integer | n,
|  | double precision, dimension(ldq,n) | q,
|  | integer | ldq,
|  | double precision, dimension(n) | qraux,
|  | double precision, dimension(m) | b,
|  | double precision, dimension(m) | qtb
| ) |  |

Definition at line 39 of file qrutil.f90.

Here is the caller graph for this function:

subroutine rsolve | ( | integer | m,
|  | integer | n,
|  | double precision, dimension(ldq,n) | q,
|  | integer | ldq,
|  | double precision, dimension(n) | qraux,
|  | double precision, dimension(n) | qtb,
|  | double precision, dimension(m) | x,
|  | logical | rcalc,
|  | double precision, dimension(m) | rsd
| ) |  |

Definition at line 117 of file qrutil.f90.

Here is the caller graph for this function: